@@ -1,6 +1,6 @@
 package Koha::Contrib::Tamil::Authority::Task;
 {
-  $Koha::Contrib::Tamil::Authority::Task::VERSION = '0.016';
+  $Koha::Contrib::Tamil::Authority::Task::VERSION = '0.017';
 }
 # ABSTRACT: Base class for managing authorities manipulations
 use Moose;
@@ -10,7 +10,7 @@ extends 'AnyEvent::Processor';
 use 5.010;
 use utf8;
 use Carp;
-use YAML::Syck;
+use YAML;
 
 has conf_authorities => ( is => 'rw', isa => 'ArrayRef' );
 
@@ -30,7 +30,6 @@ has conf_file => (
 
 no Moose;
 __PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -44,7 +43,7 @@ Koha::Contrib::Tamil::Authority::Task - Base class for managing authorities mani
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
